@@ -86,6 +86,10 @@ calc_sumstats <- function(model, segsites_list = NULL, trees = NULL,
   if (requires_segsites(model)) {
     assert_that(!is.null(segsites_list))
     assert_that(all(vapply(segsites_list, is_segsites, logical(1))))
+
+    if (has_ign_singletons(model)) {
+      segsites_list <- remove_singletons(segsites_list)
+    }
   }
   if (requires_trees(model)) assert_that(!is.null(trees))
   if (requires_files(model)) assert_that(!is.null(files))
@@ -135,7 +139,10 @@ calc_sumstats_from_sim <- function(seg_sites, trees, files, model,
 #' @param model The coala model. The summary statistics present in this model
 #'   will be calculated. The model should fit to the data, in particular
 #'   regarding the number of loci and haploids.
-#' @param segsites_list A list of \code{segsites} objects. See above.
+#' @param segsites_list Either a list of \code{segsites} objects, or an object
+#'   that can be converted using \code{\link{as.segsites}}. It is possible
+#'   to specify additional argument for the conversion using the \code{...}
+#'   argument.
 #' @param tree_list Not yet implemented.
 #' @param trios If your model is using locus trios, then you need
 #'   can create these by combining individual loci. This is a list that defines
@@ -144,11 +151,14 @@ calc_sumstats_from_sim <- function(seg_sites, trees, files, model,
 #'   summary statistics is locus in the provided data that corresponds to the
 #'   number. If three number are provided, the locus for calculation is created
 #'   by combining the corresponding three loci from the given data.
+#' @param ... Additional arguments that will be pass to
+#'   \code{\link{as.segsites}}.
 #' @export
 calc_sumstats_from_data <- function(model,
                                     segsites_list = NULL,
                                     tree_list = NULL,
-                                    trios = NULL) {
+                                    trios = NULL,
+                                    ...) {
 
   assert_that(is.model(model))
 
@@ -170,7 +180,7 @@ calc_sumstats_from_data <- function(model,
   }
 
   if (!is.null(segsites_list)) {
-    assert_that(is.list(segsites_list))
+    segsites_list <- as.segsites(segsites_list, ...)
     if (!all(vapply(segsites_list, is_segsites, logical(1)))) {
       stop("Incorrect or missing data in list of segregating sites")
     }
