@@ -12,7 +12,7 @@ stat_sfs_class <- R6Class("stat_sfs", inherit = sumstat_class,
     },
     calculate = function(seg_sites, trees, files, model) {
       individuals <- get_population_indiviuals(model, private$population)
-      sfs <- as.vector(calc_jsfs(seg_sites, individuals, numeric()))
+      sfs <- as.vector(calc_jsfs(seg_sites, list(individuals)))
       sfs[c(-1, -length(sfs))]
     }
   )
@@ -25,6 +25,11 @@ stat_sfs_class <- R6Class("stat_sfs", inherit = sumstat_class,
 #'   calculated, or \code{"all"} to calculate the combined SFS of all
 #'   populations.
 #' @export
+#' @examples
+#' set.seed(50)
+#' model <- coal_model(5, 2) + feat_mutation(5) + sumstat_sfs()
+#' stats <- simulate(model)
+#' print(stats$sfs)
 sumstat_sfs <- function(name = "sfs", population = "all",
                         transformation = identity) {
   stat_sfs_class$new(name, population, transformation)
