@@ -1,32 +1,63 @@
 context("SumStat JSFS")
 
 test_that("calculation of the JSFS is correct", {
+  seg.sites.3.pop <- list(create_segsites(matrix(c(1, 0, 1, 0,
+                                                   1, 1, 0, 1,
+                                                   0, 0, 0, 1,
+                                                   1, 0, 0, 1,
+                                                   1, 1, 1, 1,
+                                                   1, 0, 1, 0,
+                                                   1, 0, 1 ,0 ),
+                                                 nrow=7, ncol=4, byrow = TRUE),
+                                          c(0.1, 0.2, 0.5, 0.7)))
+  jsfs.3.pop <- calc_jsfs(seg.sites.3.pop, list(1:2, 3:4, 5:7))
+  expect_is(jsfs.3.pop, "array")
+  expect_equivalent(jsfs.3.pop, array(c(0, 0, 0, 0, 0, 0, 0, 0, 0,
+                                        0, 1, 0, 0, 0, 0, 0, 1, 0,
+                                        0, 0, 0, 0, 0, 0, 0, 0, 0,
+                                        0, 1, 0, 0, 0, 1, 0, 0, 0 ), dim=c(2,2,3)+1))
+
+
+  seg.sites.3.pop <- list(create_segsites(matrix(c(1, 0, 1, 0,
+                                                   1, 1, 0, 1,
+                                                   0, 0, 1, 1,
+                                                   0, 0, 0, 1,
+                                                   1, 1, 1, 1,
+                                                   1, 0, 1, 0,
+                                                   1, 0, 1 ,0 ),
+                                                 nrow=7, ncol=4, byrow = TRUE),
+                                          c(0.1, 0.2, 0.5, 0.7)))
+  jsfs.3.pop <- calc_jsfs(seg.sites.3.pop, list(1, 2:6, 7))
+  expect_equivalent(jsfs.3.pop, array(c(0, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0,
+                                        0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0 ), dim=c(1,5,1)+1))
+  
   seg.sites <- list(create_segsites(matrix(c(1, 0, 1, 0,
                                              1, 1, 0, 1,
                                              0, 0, 0, 1,
                                              1, 0, 0, 1), 4, 4, byrow = TRUE),
                                     c(0.1, 0.2, 0.5, 0.7)))
 
-  jsfs <- calc_jsfs(seg.sites, 1:2, 3:4)
-  expect_equal(jsfs, matrix(c(0, 0, 0,
-                              2, 0, 1,
-                              0, 1, 0), 3, 3, byrow = TRUE))
+  jsfs <- calc_jsfs(seg.sites, list(1:2, 3:4))
+  expect_is(jsfs, "matrix")
+  expect_equivalent(jsfs, matrix(c(0, 0, 0,
+                                   2, 0, 1,
+                                   0, 1, 0), 3, 3, byrow = TRUE))
 
-  jsfs <- calc_jsfs(seg.sites, 1, 2:4)
-  expect_equal(jsfs, matrix(c(0, 1, 0, 1,
-                              1, 0, 1, 0), 2, 4, byrow = TRUE))
+  jsfs <- calc_jsfs(seg.sites, list(1, 2:4))
+  expect_equivalent(jsfs, matrix(c(0, 1, 0, 1,
+                                   1, 0, 1, 0), 2, 4, byrow = TRUE))
 
-  jsfs2 <- calc_jsfs(seg.sites, 2:4, 1)
-  expect_equal(jsfs2, t(jsfs))
+  jsfs2 <- calc_jsfs(seg.sites, list(2:4, 1))
+  expect_equivalent(jsfs2, t(jsfs))
 
-  jsfs <- calc_jsfs(seg.sites, c(1,3), c(2,4))
-  expect_equal(jsfs, matrix(c(0, 1, 0,
-                              1, 0, 2,
-                              0, 0, 0), 3, 3, byrow = TRUE))
+  jsfs <- calc_jsfs(seg.sites, list(c(1,3), c(2,4)))
+  expect_equivalent(jsfs, matrix(c(0, 1, 0,
+                                   1, 0, 2,
+                                   0, 0, 0), 3, 3, byrow = TRUE))
 
   expect_error(calc_jsfs(seg.sites, c(1,3), c(2,5)))
   expect_error(calc_jsfs(seg.sites, c(1,7), c(2,3)))
-  calc_jsfs(seg.sites, numeric(), 1:4)
+  calc_jsfs(seg.sites, list(numeric(), 1:4))
 
 
   seg.sites <- list(create_segsites(matrix(c(1, 1, 1, 1,
@@ -34,7 +65,7 @@ test_that("calculation of the JSFS is correct", {
                                              1, 1, 0, 0), 4, 3),
                                     c(0.1, 0.5, 0.7)))
 
-  jsfs <- calc_jsfs(seg.sites, 1:2, 3:4)
+  jsfs <- calc_jsfs(seg.sites, list(1:2, 3:4))
   expect_true(is.matrix(jsfs))
   expect_equal(dim(jsfs), c(3, 3))
   expect_equal(sum(jsfs), 2)
@@ -46,7 +77,7 @@ test_that("calculation of the JSFS is correct", {
                                              0, 1, 1, 1,
                                              0, 1, 1, 1),  4, 3),
                                     c(0.1, 0.5, 0.7))
-  jsfs <- calc_jsfs(seg.sites, 1:2, 3:4)
+  jsfs <- calc_jsfs(seg.sites, list(1:2, 3:4))
   expect_true(is.matrix(jsfs))
   expect_equal(dim(jsfs), c(3, 3))
   expect_equal(sum(jsfs), 5)
@@ -56,7 +87,7 @@ test_that("calculation of the JSFS is correct", {
 
 
   seg.sites[[3]] <- create_empty_segsites(4)
-  jsfs <- calc_jsfs(seg.sites, 1:2, 3:4)
+  jsfs <- calc_jsfs(seg.sites, list(1:2, 3:4))
   expect_true(is.matrix(jsfs))
   expect_equal(dim(jsfs), c(3, 3))
   expect_equal(sum(jsfs), 5)
@@ -76,10 +107,10 @@ test_that("calc_jsfs works with trios", {
                                     rep(c(0.1, 0.2, 0.5, 0.7), 3),
                                     rep(c(-1, 0, 1), each = 4)))
 
-  jsfs <- calc_jsfs(seg.sites, 1:2, 3:4)
-  expect_equal(jsfs, matrix(c(0, 0, 0,
-                              1, 0, 1,
-                              0, 0, 0), 3, 3, byrow = TRUE))
+  jsfs <- calc_jsfs(seg.sites, list(1:2, 3:4))
+  expect_equivalent(jsfs, matrix(c(0, 0, 0,
+                                   1, 0, 1,
+                                   0, 0, 0), 3, 3, byrow = TRUE))
 })
 
 
@@ -94,10 +125,10 @@ test_that("JSFS sumstat works", {
                                     c(0.1, 0.2, 0.5, 0.7)))
 
   expect_equal(stat$get_name(), "jsfs_test")
-  expect_equal(stat$calculate(seg_sites, NULL, NULL, model),
-               matrix(c(0, 0, 0,
-                        1, 0, 1,
-                        0, 0, 0), 3, 3, byrow = TRUE))
+  expect_equivalent(stat$calculate(seg_sites, NULL, NULL, model),
+                    matrix(c(0, 0, 0,
+                             1, 0, 1,
+                             0, 0, 0), 3, 3, byrow = TRUE))
 })
 
 
@@ -109,19 +140,19 @@ test_that("JSFS is caluculated with an outgroup present", {
                                              1, 0, 0, 1), 3, 4, byrow = TRUE),
                                     1:4/4))
 
-  expect_equal(stat$calculate(seg_sites, NULL, NULL, model),
-               matrix(c(0, 0,
-                        1, 1,
-                        0, 0), 3, 2, byrow = TRUE))
+  expect_equivalent(stat$calculate(seg_sites, NULL, NULL, model),
+                    matrix(c(0, 0,
+                             1, 1,
+                             0, 0), 3, 2, byrow = TRUE))
 
   model <- coal_model(c(2, 1, 1), 1) + feat_outgroup(2)
   expect_error(stat$calculate(seg_sites, NULL, NULL, model))
 
   stat <- sumstat_jsfs("jsfs", c(1, 3))
-  expect_equal(stat$calculate(seg_sites, NULL, NULL, model),
-               matrix(c(0, 0,
-                        1, 1,
-                        0, 0), 3, 2, byrow = TRUE))
+  expect_equivalent(stat$calculate(seg_sites, NULL, NULL, model),
+                    matrix(c(0, 0,
+                             1, 1,
+                             0, 0), 3, 2, byrow = TRUE))
 })
 
 
